// ----------------------------------------------------------------------------------
// Microsoft Developer & Platform Evangelism
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// ----------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
// ----------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace CarGeneration
{
    class Program
    {
        static List<string> makes;
        static Dictionary<string, List<string>> models;
        static List<string> colors;
        static List<string> interior;
        static List<string> transmission;

        static void Main(string[] args)
        {
            PopulateLookups();

            var random = new Random();
            using (var writer = new StreamWriter("cars.csv", false))
            {
                for (int i = 0; i < 2000000; i++)
                {
                    var year = random.Next(1990, 2008);
                    var makeIndex = random.Next(0, makes.Count);
                    var modelIndex = random.Next(0, models[makes[makeIndex]].Count);
                    var transmissionIndex = random.Next(0, transmission.Count);
                    var exteriorColorIndex = random.Next(0, colors.Count);
                    var interiorMaterialIndex = random.Next(0, interior.Count);
                    var mileage = random.Next(5000, 95000);
                    var mpg = random.Next(10, 40);
                    var price = random.Next(15000, 70000);
                    var satelliteRadio = random.Next(0, 2);
                    var moonRoof = random.Next(0, 2);
                    var heatedSeats = random.Next(0, 2);
                    var gps = random.Next(0, 2);

                    writer.WriteLine("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10},{11},{12}",
                        year,
                        makes[makeIndex],
                        models[makes[makeIndex]][modelIndex],
                        transmission[transmissionIndex],
                        colors[exteriorColorIndex],
                        interior[interiorMaterialIndex],
                        mileage,
                        mpg,
                        price,
                        satelliteRadio,
                        moonRoof,
                        heatedSeats,
                        gps);

                    if (i % 10000 == 0)
                    {
                        Console.WriteLine("{0} cars generated", i);
                    }
                }
            }
        }

        static void PopulateLookups()
        {
            makes = new List<string>() { "Acura", "Aston Martin", "Audi", "Bentley", "BMW", "Ford", "Hyundai", "Toyota", "Honda", "Lotus", "Subaru" };

            models = new Dictionary<string, List<string>>()
            {
                { "Acura", new List<string>() { "Integra","Legend","MDX","NSX","RSX","TL" } },
                { "Aston Martin", new List<string>() { "DB7","DB9","Vanquish","Vantage" } },
                { "Audi", new List<string>() { "A4","A8","RS6","S4","S8","TT" } },
                { "Bentley", new List<string>() { "Continental" } },
                { "BMW", new List<string>() { "323ci","325is","330i","528xi","535xi","545i","550i","645ci" } },
                { "Ferrari", new List<string>() { "F40","Enzo" } },
                { "Ford", new List<string>() { "Mercury","Mustang","Escort","Focus" } },
                { "Hyundai", new List<string>() { "Elantra" } },
                { "Toyota", new List<string>() { "Corolla" } },
                { "Honda", new List<string>() { "Civic","Accord" } },
                { "Lotus", new List<string>() { "Elise" } },
                { "Subaru", new List<string>() { "Outback" } }
            };

            colors = new List<string>
            {
                "Black","Blue","Bronze","Burgundy","Charcoal","Crimson","Dark Blue","Dark Gray",
                "Dark Green","Gray","Green","Light Blue","Light Green","Light Silver","Maroon",
                "Purple","Red","Silver","Tan","Teal","White","Yellow"
            };

            transmission = new List<string>() { "Manual", "Automatic" };

            interior = new List<string>() { "Leather", "Cloth", "Suede" };
        }
    }
}