// ----------------------------------------------------------------------------------
// Microsoft Developer & Platform Evangelism
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// ----------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
// ----------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using ContosoAutomotive.Common;

namespace ContosoAutomotive.Queries
{
    public abstract class CarQueryBase : ICarQuery, INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private string _name;
        public string Name
        {
            get { return _name; }
            set { _name = value; NotifyPropertyChanged("Name"); }
        }

        private string _description;
        public string Description
        {
            get { return _description; }
            set { _description = value; NotifyPropertyChanged("Description"); }
        }

        private string _imagePath;
        public string ImagePath
        {
            get { return _imagePath; }
            set { _imagePath = value; NotifyPropertyChanged("ImagePath"); }
        }

        private QueryStatus _status = QueryStatus.NotStarted;
        public QueryStatus Status
        {
            get { return _status; }
            set { _status = value; NotifyPropertyChanged("Status"); }
        }

        private List<Car> _results;
        public List<Car> Results
        {
            get { return _results; }
            set { _results = value; ResultsCount = _results.Count(); NotifyPropertyChanged("Results"); }
        }

        private int _resultsCount;
        public int ResultsCount
        {
            get { return _resultsCount; }
            set { _resultsCount = value; NotifyPropertyChanged("ResultsCount"); }
        }

        private void NotifyPropertyChanged(string name)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(name));
            }
        }

        public void Run(IEnumerable<Car> cars, bool longRunning)
        {
            Status = QueryStatus.Running;

            if (longRunning)
            {
                System.Threading.Thread.SpinWait(80000000);
            }

            Results = RunQuery(cars).ToList();

            Status = QueryStatus.Finished;
        }

        protected abstract IEnumerable<Car> RunQuery(IEnumerable<Car> cars);
    }
}