// ----------------------------------------------------------------------------------
// Microsoft Developer & Platform Evangelism
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// ----------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
// ----------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace ContosoAutomotive.Common
{
    public class CarGenerator
    {
        private Random random;
        private List<string> makes;
        private Dictionary<string, List<string>> models;
        private List<string> colors;
        private List<string> interior;
        private List<string> transmission;

        public CarGenerator()
        {
            random = new Random();
            PopulateLookups();
        }

        public Car Generate()
        {
            var year = random.Next(1990, 2008);
            var makeIndex = random.Next(0, makes.Count);
            var modelIndex = random.Next(0, models[makes[makeIndex]].Count);
            var transmissionIndex = random.Next(0, transmission.Count);
            var exteriorColorIndex = random.Next(0, colors.Count);
            var interiorMaterialIndex = random.Next(0, interior.Count);
            var mileage = random.Next(5000, 95000);
            var mpg = random.Next(10, 40);
            var price = random.Next(15000, 70000);
            var satelliteRadio = random.Next(0, 2);
            var moonRoof = random.Next(0, 2);
            var heatedSeats = random.Next(0, 2);
            var gps = random.Next(0, 2);

            var car = new Car();
            car.Year = year;
            car.Make = makes[makeIndex];
            car.Model = models[makes[makeIndex]][modelIndex];
            car.Transmission = (Transmission)Enum.Parse(typeof(Transmission), transmission[transmissionIndex]);
            car.Color = colors[exteriorColorIndex];
            car.Interior = (InteriorType)Enum.Parse(typeof(InteriorType), interior[interiorMaterialIndex]);
            car.Mileage = mileage;
            car.MPG = mpg;
            car.Price = price;
            car.SatelliteRadio = (satelliteRadio == 0) ? false : true;
            car.MoonRoof = (moonRoof == 0) ? false : true;
            car.HeatedSeats = (heatedSeats == 0) ? false : true;
            car.GPS = (gps == 0) ? false : true;

            return car;
        }

        private void PopulateLookups()
        {
            makes = new List<string>() { "Acura", "Aston Martin", "Audi", "Bentley", "BMW", "Ford", "Hyundai", "Toyota", "Honda", "Lotus", "Subaru", "Ferrari" };

            models = new Dictionary<string, List<string>>()
            {
                { "Acura", new List<string>() { "Integra","Legend","MDX","NSX","RSX","TL" } },
                { "Aston Martin", new List<string>() { "DB7","DB9","Vanquish","Vantage" } },
                { "Audi", new List<string>() { "A4","A8","RS6","S4","S8","TT" } },
                { "Bentley", new List<string>() { "Continental" } },
                { "BMW", new List<string>() { "323ci","325is","330i","528xi","535xi","545i","550i","645ci" } },
                { "Ferrari", new List<string>() { "F40","Enzo" } },
                { "Ford", new List<string>() { "Mercury","Mustang","Escort","Focus" } },
                { "Hyundai", new List<string>() { "Elantra" } },
                { "Toyota", new List<string>() { "Corolla" } },
                { "Honda", new List<string>() { "Civic","Accord" } },
                { "Lotus", new List<string>() { "Elise" } },
                { "Subaru", new List<string>() { "Outback" } }
            };

            colors = new List<string>
            {
                "Black","Blue","Bronze","Burgundy","Charcoal","Crimson","Dark Blue","Dark Gray",
                "Dark Green","Gray","Green","Light Blue","Light Green","Light Silver","Maroon",
                "Purple","Red","Silver","Tan","Teal","White","Yellow"
            };

            transmission = new List<string>() { "Manual", "Automatic" };

            interior = new List<string>() { "Leather", "Cloth", "Suede" };
        }
    }
}